summaryrefslogtreecommitdiff
path: root/src/process.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/process.c')
-rw-r--r--src/process.c11
1 files changed, 7 insertions, 4 deletions
diff --git a/src/process.c b/src/process.c
index 6cbdfed1f59..e07a019b464 100644
--- a/src/process.c
+++ b/src/process.c
@@ -6795,10 +6795,13 @@ emacs_get_tty_pgrp (struct Lisp_Process *p)
DEFUN ("process-running-child-p", Fprocess_running_child_p,
Sprocess_running_child_p, 0, 1, 0,
- doc: /* Return non-nil if PROCESS has given the terminal to a
-child. If the operating system does not make it possible to find out,
-return t. If we can find out, return the numeric ID of the foreground
-process group. */)
+ doc: /* Return non-nil if PROCESS has given control of its terminal to a child.
+If the operating system does not make it possible to find out, return t.
+If it's possible to find out, return the numeric ID of the foreground
+process group if PROCESS did give control of its terminal to a
+child process, and return nil if it didn't.
+
+PROCESS must be a real subprocess, not a connection. */)
(Lisp_Object process)
{
/* Initialize in case ioctl doesn't exist or gives an error,